@@ -6,24 +6,14 @@ term = Term()
 
 
 p = """
- ___         _    _           
-| _ \_  _ __| |_ (_)_ _  __ _ 
-|  _/ || (_-< ' \| | ' \/ _` |
-|_|  \_,_/__/_||_|_|_||_\__, |
-                         |___/
+  ____             __ _                                 _   
+ / ___|___  _ __  / _(_)_ __   ___ _ __ ___   ___ _ __ | |_ 
+| |   / _ \| '_ \| |_| | '_ \ / _ \ '_ ` _ \ / _ \ '_ \| __|
+| |__| (_) | | | |  _| | | | |  __/ | | | | |  __/ | | | |_ 
+ \____\___/|_| |_|_| |_|_| |_|\___|_| |_| |_|\___|_| |_|\__|
+                                                            
 """
-o = ("""
-  ___       _      _             _   
- / _ \ _  _| |_ __| |_  ___  ___| |_ 
-| (_) | || |  _(_-< ' \/ _ \/ _ \  _|
- \___/ \_,_|\__/__/_||_\___/\___/\__|
-""")
-u = ("""
- _   _       __     _    _ 
-| | | |_ _  / _|___| |__| |
-| |_| | ' \|  _/ _ \ / _` |
- \___/|_||_|_| \___/_\__,_|
-""")
+u = o = ""
 s = f"""
 {term.grey('"Remebering the Pandemic"')}
 
