@@ -4,9 +4,9 @@ import random
 term = Term()
 
 def addition():
-	a = random.randint(0, 100) # Pick a number between 0 and 100
-	b = random.randint(0, 100) # Pick another number between 0 and 100
-	real_answer = str(a + b)
+	a = random.randint(0, 30) # Pick a number between 0 and 100
+	b = random.randint(0, 30) # Pick another number between 0 and 100
+	real_answer = str(round(a + b))
 	user_answer = input(f"What is {a} + {b}? ")
 	if real_answer == user_answer:
 		print(term.green('Correct!'))
@@ -14,9 +14,9 @@ def addition():
 		print(term.red(f'Incorrect! The correct answer was `{real_answer}`'))
 
 def subtraction():
-	a = random.randint(0,100) # Pick a number between 0 and 100
-	b = random.randint(0,100) #Pick aanother number between 0 and 100
-	real_answer = str(a - b)
+	a = random.randint(0,30) # Pick a number between 0 and 100
+	b = random.randint(0,30) #Pick another number between 0 and 100
+	real_answer = str(round(a - b))
 	user_answer = input(f"What is {a} - {b}? ")
 	if real_answer == user_answer:
 		print(term.green('Correct!'))
@@ -24,9 +24,9 @@ def subtraction():
 		print(term.red(f'Incorrect! The correct answer was `{real_answer}`'))
 
 def multiplication():
-	a = random.randint(0,100) # Pick a number between 0 and 100
-	b = random.randint(0,100) # Pick a number between 0 and 100
-	real_answer = str(a *b)
+	a = random.randint(0,30) # Pick a number between 0 and 100
+	b = random.randint(0,30) # Pick a number between 0 and 100
+	real_answer = str(round(a * b))
 	user_answer = input(f"What is {a} * {b}? ")
 	if real_answer == user_answer:
 		print(term.green('Correct!'))
@@ -34,9 +34,13 @@ def multiplication():
 		print('Incorrect')
 
 def division():
-	a = random.randint(0,100) # Pick a number between 0 and 100
-	b = random.randint(0,100) # Pick a number between 0 and 100
-	real_answer = str(a / b)
+	return
+	a = random.randint(0,30) # Pick a number between 0 and 100
+	b = random.randint(0,30) # Pick a number between 0 and 100\
+	answer = a / b
+	if round(answer) == answer:
+		answer = round(answer)
+	real_answer = str(round(a / b))
 	user_answer = input(f"What is {a} / {b}? ")
 	if real_answer == user_answer:
 		print(term.green('Correct!'))
